┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphincontroller.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2007-10-02 22:04:36 +0000
committerPeter Penz <[email protected]>2007-10-02 22:04:36 +0000
commit3c1c185400a55103cea3ed567de167df87b59945 (patch)
treecb795f1bb1582e9728634f31d66e1fc989a7c087 /src/dolphincontroller.h
parentba150e5735bd336752f713df1e9f66b7ed90e6ae (diff)
Allow showing additional information like type, size and date in parallel for the icons view (thanks to Fredrik for the extension of KFileItemDelegate!).
svn path=/trunk/KDE/kdebase/apps/; revision=720283
Diffstat (limited to 'src/dolphincontroller.h')
-rw-r--r--src/dolphincontroller.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/dolphincontroller.h b/src/dolphincontroller.h
index d17f34c75..d773a8548 100644
--- a/src/dolphincontroller.h
+++ b/src/dolphincontroller.h
@@ -77,8 +77,8 @@ public:
void setShowPreview(bool show);
bool showPreview() const;
- void setShowAdditionalInfo(bool show);
- bool showAdditionalInfo() const;
+ void setAdditionalInfoCount(int count);
+ bool additionalInfoCount() const;
void triggerZoomIn();
void setZoomInPossible(bool possible);
@@ -156,10 +156,10 @@ signals:
void showPreviewChanged(bool show);
/**
* Is emitted if the state for showing additional info has been
* changed to \a show.
*/
- void showAdditionalInfoChanged(bool show);
+ void additionalInfoCountChanged(int count);
/**
* Is emitted if the item with the index \a index should be triggered.
@@ -188,9 +188,9 @@ signals:
private:
bool m_showPreview;
- bool m_showAdditionalInfo;
bool m_zoomInPossible;
bool m_zoomOutPossible;
+ int m_additionalInfoCount;
KUrl m_url;
};
@@ -204,9 +204,9 @@ inline bool DolphinController::showPreview() const
return m_showPreview;
}
-inline bool DolphinController::showAdditionalInfo() const
+inline bool DolphinController::additionalInfoCount() const
{
- return m_showAdditionalInfo;
+ return m_additionalInfoCount;
}
inline void DolphinController::setZoomInPossible(bool possible)
@@ -156,10 +156,10 @@ signals:
void showPreviewChanged(bool show);
/**
- * Is emitted if the state for showing additional info has been
- * changed to \a show.
+ * Is emitted if the number of additional informations has been
+ * changed to \a count.
*/